@@ -14,26 +14,25 @@
 #include "mem-types.h"
 #include "circ-buff.h"
 
-struct event_hist
-{
-        buffer_t *buffer;
-        pthread_mutex_t lock;
+struct event_hist {
+    buffer_t *buffer;
+    pthread_mutex_t lock;
 };
 
 typedef struct event_hist eh_t;
 
 void
-eh_dump (eh_t *event , void *data,
-         int (fn) (circular_buffer_t *buffer, void *data));
+eh_dump(eh_t *event, void *data,
+        int(fn)(circular_buffer_t *buffer, void *data));
 
 eh_t *
-eh_new (size_t buffer_size, gf_boolean_t use_buffer_once,
-        void (*destroy_data) (void *data));
+eh_new(size_t buffer_size, gf_boolean_t use_buffer_once,
+       void (*destroy_data)(void *data));
 
 int
-eh_save_history (eh_t *history, void *string);
+eh_save_history(eh_t *history, void *string);
 
 int
-eh_destroy (eh_t *history);
+eh_destroy(eh_t *history);
 
 #endif /* _EH_H */
